@@ -38,6 +38,9 @@
 #include "common/xfpm-power-common.h"
 #include "common/xfpm-brightness.h"
 #include "common/xfpm-debug.h"
+#ifdef XFPM_SYSTRAY
+#include "src/xfpm-inhibit.h"
+#endif
 
 #include "power-manager-button.h"
 #include "scalemenuitem.h"
@@ -55,14 +58,15 @@ struct PowerManagerButtonPrivate
 {
 #ifdef XFCE_PLUGIN
     XfcePanelPlugin *plugin;
+    GDBusProxy      *inhibit_proxy;
+#else
+    XfpmInhibit     *inhibit;
 #endif
 
     XfconfChannel   *channel;
 
     UpClient        *upower;
 
-    GDBusProxy      *inhibit_proxy;
-
     /* A list of BatteryDevices  */
     GList           *devices;
 
@@ -134,7 +138,7 @@ G_DEFINE_TYPE (PowerManagerButton, power_manager_button, GTK_TYPE_TOGGLE_BUTTON)
 
 static void power_manager_button_finalize   (GObject *object);
 static GList* find_device_in_list (PowerManagerButton *button, const gchar *object_path);
-static gboolean power_manager_button_device_icon_expose (GtkWidget *img, GdkEventExpose *event, gpointer userdata);
+static gboolean power_manager_button_device_icon_draw (GtkWidget *img, cairo_t *cr, gpointer userdata);
 static void power_manager_button_set_icon (PowerManagerButton *button);
 static void power_manager_button_set_label (PowerManagerButton *button, gdouble percentage, guint64 time_to_empty_or_full);
 static void power_manager_button_update_label (PowerManagerButton *button, UpDevice *device);
@@ -326,9 +330,8 @@ power_manager_button_set_label (PowerManagerButton *button, gdouble percentage,
 }
 
 static gboolean
-power_manager_button_device_icon_expose (GtkWidget *img, GdkEventExpose *event, gpointer userdata)
+power_manager_button_device_icon_draw (GtkWidget *img, cairo_t *cr, gpointer userdata)
 {
-    cairo_t *cr;
     UpDevice *device = NULL;
     guint type = 0, state = 0;
     gdouble percentage;
@@ -367,7 +370,6 @@ power_manager_button_device_icon_expose (GtkWidget *img, GdkEventExpose *event,
 
     gtk_widget_get_allocation (img, &allocation);
 
-    cr = gdk_cairo_create (gtk_widget_get_window (img));
     width = allocation.width;
     height = allocation.height;
 
@@ -423,7 +425,6 @@ power_manager_button_device_icon_expose (GtkWidget *img, GdkEventExpose *event,
         pango_cairo_show_layout (cr, layout);
     }
 
-    cairo_destroy (cr);
     if (layout)
         g_object_unref (layout);
     return FALSE;
@@ -490,21 +491,10 @@ power_manager_button_update_device_icon_and_details (PowerManagerButton *button,
         /* update the icon */
         g_free (button->priv->panel_icon_name);
 #ifdef XFCE_PLUGIN
-        g_object_get (device,
-                      "icon-name", &icon_name,
-                      NULL);
-
-        /* ignore empty icon names */
-        if (g_strcmp0(icon_name, "") == 0)
-        {
-            g_free (icon_name);
-            icon_name = NULL;
-        }
-
-        if (icon_name == NULL)
-            icon_name = g_strdup (PANEL_DEFAULT_ICON_SYMBOLIC);
-#endif
+        button->priv->panel_icon_name = g_strdup_printf ("%s-%s", icon_name, "symbolic");
+#else
         button->priv->panel_icon_name = g_strdup (icon_name);
+#endif
         power_manager_button_set_icon (button);
         /* update the tooltip */
         power_manager_button_set_tooltip (button);
@@ -527,7 +517,7 @@ G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 G_GNUC_END_IGNORE_DEPRECATIONS
         battery_device->expose_signal_id = g_signal_connect_after (G_OBJECT (battery_device->img),
                                                                    "draw",
-                                                                   G_CALLBACK (power_manager_button_device_icon_expose),
+                                                                   G_CALLBACK (power_manager_button_device_icon_draw),
                                                                    device);
     }
 }
@@ -909,6 +899,24 @@ power_manager_button_class_init (PowerManagerButtonClass *klass)
 #undef XFPM_PARAM_FLAGS
 }
 
+#ifdef XFCE_PLUGIN
+static void
+inhibit_proxy_ready_cb (GObject *source_object,
+                        GAsyncResult *res,
+                        gpointer user_data)
+{
+    GError *error = NULL;
+    PowerManagerButton *button = POWER_MANAGER_BUTTON (user_data);
+
+    button->priv->inhibit_proxy = g_dbus_proxy_new_finish (res, &error);
+    if (error != NULL)
+    {
+        g_warning ("error getting inhibit proxy: %s", error->message);
+        g_clear_error (&error);
+    }
+}
+#endif
+
 static void
 power_manager_button_init (PowerManagerButton *button)
 {
@@ -920,7 +928,11 @@ power_manager_button_init (PowerManagerButton *button)
     gtk_widget_set_can_default (GTK_WIDGET (button), FALSE);
     gtk_widget_set_can_focus (GTK_WIDGET (button), FALSE);
     gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
+#if !GTK_CHECK_VERSION (3, 20, 0)
     gtk_button_set_focus_on_click (GTK_BUTTON (button), FALSE);
+#else
+    gtk_widget_set_focus_on_click (GTK_WIDGET (button), FALSE);
+#endif
     gtk_widget_set_name (GTK_WIDGET (button), "xfce4-power-manager-plugin");
 
     button->priv->brightness = xfpm_brightness_new ();
@@ -938,22 +950,19 @@ power_manager_button_init (PowerManagerButton *button)
         button->priv->channel = xfconf_channel_get ("xfce4-power-manager");
     }
 
-    button->priv->inhibit_proxy = g_dbus_proxy_new_sync (g_bus_get_sync (G_BUS_TYPE_SESSION,
-                                                                         NULL,
-                                                                         NULL),
-                                                         G_DBUS_PROXY_FLAGS_NONE,
-                                                         NULL,
-                                                         "org.freedesktop.PowerManagement",
-                                                         "/org/freedesktop/PowerManagement/Inhibit",
-                                                         "org.freedesktop.PowerManagement.Inhibit",
-                                                         NULL,
-                                                         &error);
-
-    if (error != NULL)
-    {
-        g_warning ("error getting inhibit proxy: %s", error->message);
-        g_clear_error (&error);
-    }
+#ifdef XFCE_PLUGIN
+    g_dbus_proxy_new (g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, NULL),
+                      G_DBUS_PROXY_FLAGS_NONE,
+                      NULL,
+                      "org.freedesktop.PowerManagement",
+                      "/org/freedesktop/PowerManagement/Inhibit",
+                      "org.freedesktop.PowerManagement.Inhibit",
+                      NULL,
+                      inhibit_proxy_ready_cb,
+                      button);
+#else
+    button->priv->inhibit = xfpm_inhibit_new ();
+#endif
 
     /* Sane defaults for the systray and panel icon */
 #ifdef XFCE_PLUGIN
@@ -967,10 +976,6 @@ power_manager_button_init (PowerManagerButton *button)
     css_provider = gtk_css_provider_new ();
     gtk_css_provider_load_from_data (css_provider,
                                      "#xfce4-power-manager-plugin {"
-                                     "-GtkWidget-focus-padding: 0;"
-                                     "-GtkWidget-focus-line-width: 0;"
-                                     "-GtkButton-default-border: 0;"
-                                     "-GtkButton-inner-border: 0;"
                                      "padding: 1px;"
                                      "border-width: 1px;}",
                                      -1, NULL);
@@ -1049,11 +1054,13 @@ power_manager_button_press_event (GtkWidget *widget, GdkEventButton *event)
 static void
 power_manager_button_size_changed_cb (XfcePanelPlugin *plugin, gint size, PowerManagerButton *button)
 {
+#if !LIBXFCE4PANEL_CHECK_VERSION (4, 13, 0)
     GtkStyleContext *context;
     GtkBorder padding, border;
     gint width;
     gint xthickness;
     gint ythickness;
+#endif
 
     g_return_if_fail (POWER_MANAGER_IS_BUTTON (button));
     g_return_if_fail (XFCE_IS_PANEL_PLUGIN (plugin));
@@ -1061,6 +1068,9 @@ power_manager_button_size_changed_cb (XfcePanelPlugin *plugin, gint size, PowerM
 
     size /= xfce_panel_plugin_get_nrows (plugin);
 
+#if LIBXFCE4PANEL_CHECK_VERSION (4, 13, 0)
+    button->priv->panel_icon_width = xfce_panel_plugin_get_icon_size (plugin);
+#else
     /* Calculate the size of the widget because the theme can override it */
     context = gtk_widget_get_style_context (GTK_WIDGET (button));
     gtk_style_context_get_padding (context, gtk_widget_get_state_flags (GTK_WIDGET (button)), &padding);
@@ -1081,6 +1091,7 @@ power_manager_button_size_changed_cb (XfcePanelPlugin *plugin, gint size, PowerM
         button->priv->panel_icon_width = 32;
     else
         button->priv->panel_icon_width = width;
+#endif
 
     /* resize the plugin */
     gtk_widget_set_size_request (GTK_WIDGET (plugin), size, size);
@@ -1202,10 +1213,14 @@ power_manager_button_update_label (PowerManagerButton *button, UpDevice *device)
                   "time-to-full", &time_to_full,
                   NULL);
 
-    /* Hide the label if the battery is fully charged */
+    /* Hide the label if the battery is fully charged,
+     * if the state is unknown (no battery available)
+       or if it's a desktop system */
     if (state == UP_DEVICE_STATE_CHARGING)
         power_manager_button_set_label (button, percentage, time_to_full);
-    else if (state == UP_DEVICE_STATE_FULLY_CHARGED)
+    else if (state == UP_DEVICE_STATE_FULLY_CHARGED
+             || state == UP_DEVICE_STATE_UNKNOWN
+             || g_strcmp0 (button->priv->panel_icon_name, "ac-adapter-symbolic") == 0)
         gtk_widget_hide (GTK_WIDGET (button->priv->panel_label));
     else
         power_manager_button_set_label (button, percentage, time_to_empty);
@@ -1224,6 +1239,8 @@ menu_destroyed_cb(GtkMenuShell *menu, gpointer user_data)
     /* untoggle panel icon */
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(button), FALSE);
 
+    gtk_menu_detach (GTK_MENU (button->priv->menu));
+
     button->priv->menu = NULL;
 }
 
@@ -1305,7 +1322,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
     g_signal_connect(G_OBJECT (mi), "destroy", G_CALLBACK (menu_item_destroyed_cb), button);
     battery_device->expose_signal_id = g_signal_connect_after (G_OBJECT (battery_device->img),
                                                                "draw",
-                                                               G_CALLBACK (power_manager_button_device_icon_expose),
+                                                               G_CALLBACK (power_manager_button_device_icon_draw),
                                                                battery_device->device);
 
     /* Active calls xfpm settings with the device's id to display details */
@@ -1321,9 +1338,37 @@ G_GNUC_END_IGNORE_DEPRECATIONS
     return TRUE;
 }
 
+static void
+add_inhibitor_to_menu (PowerManagerButton *button, const gchar *text)
+{
+    GtkWidget *mi, *img;
+
+    /* Translators this is to display which app is inhibiting
+     * power in the plugin menu. Example:
+     * VLC is currently inhibiting power management
+     */
+    gchar *label = g_strdup_printf (_("%s is currently inhibiting power management"), text);
+
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+    mi = gtk_image_menu_item_new_with_label(label);
+G_GNUC_END_IGNORE_DEPRECATIONS
+    /* add the image */
+    img = gtk_image_new_from_icon_name ("gtk-info", GTK_ICON_SIZE_MENU);
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+    gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(mi), img);
+G_GNUC_END_IGNORE_DEPRECATIONS
+
+    gtk_widget_set_can_focus (mi, FALSE);
+    gtk_widget_show (mi);
+    gtk_menu_shell_append (GTK_MENU_SHELL(button->priv->menu), mi);
+    g_free (label);
+}
+
+#ifdef XFCE_PLUGIN
 static void
 display_inhibitors (PowerManagerButton *button, GtkWidget *menu)
 {
+    GtkWidget *separator_mi;
     gboolean needs_seperator = FALSE;
 
     g_return_if_fail (POWER_MANAGER_IS_BUTTON (button));
@@ -1346,7 +1391,6 @@ display_inhibitors (PowerManagerButton *button, GtkWidget *menu)
         {
             GVariantIter *iter;
             gchar        *value;
-            GtkWidget    *inhibit_mi;
 
             g_variant_get (reply, "(as)", &iter);
 
@@ -1358,27 +1402,7 @@ display_inhibitors (PowerManagerButton *button, GtkWidget *menu)
             /* Add the list of programs to the menu */
             while (g_variant_iter_next (iter, "s", &value))
             {
-                GtkWidget *mi, *img;
-
-                /* Translators this is to display which app is inhibiting
-                 * power in the plugin menu. Example:
-                 * VLC is currently inhibiting power management
-                 */
-                gchar *label = g_strdup_printf (_("%s is currently inhibiting power management"), value);
-
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-                mi = gtk_image_menu_item_new_with_label(label);
-G_GNUC_END_IGNORE_DEPRECATIONS
-                /* add the image */
-                img = gtk_image_new_from_icon_name ("gtk-info", GTK_ICON_SIZE_MENU);
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-                gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(mi), img);
-G_GNUC_END_IGNORE_DEPRECATIONS
-
-                gtk_widget_set_can_focus (mi, FALSE);
-                gtk_widget_show (mi);
-                gtk_menu_shell_append (GTK_MENU_SHELL(button->priv->menu), mi);
-                g_free (label);
+                add_inhibitor_to_menu (button, value);
             }
             g_variant_iter_free (iter);
             g_variant_unref (reply);
@@ -1391,13 +1415,42 @@ G_GNUC_END_IGNORE_DEPRECATIONS
         if (needs_seperator)
         {
             /* add a separator */
-            GtkWidget * separator_mi = gtk_separator_menu_item_new ();
+            separator_mi = gtk_separator_menu_item_new ();
             gtk_widget_show (separator_mi);
             gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator_mi);
         }
 
     }
 }
+#else
+static void
+display_inhibitors (PowerManagerButton *button, GtkWidget *menu)
+{
+    guint i;
+    GtkWidget *separator_mi;
+    const gchar **inhibitors;
+
+    g_return_if_fail (POWER_MANAGER_IS_BUTTON (button));
+    g_return_if_fail (GTK_IS_MENU (menu));
+
+    inhibitors = xfpm_inhibit_get_inhibit_list (button->priv->inhibit);
+    if (inhibitors != NULL && inhibitors[0] != NULL)
+    {
+        for (i=0; inhibitors[i] != NULL; i++)
+        {
+            add_inhibitor_to_menu (button, inhibitors[i]);
+        }
+
+        /* add a separator */
+        separator_mi = gtk_separator_menu_item_new ();
+        gtk_widget_show (separator_mi);
+        gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator_mi);
+    }
+
+    g_free (inhibitors);
+}
+#endif
+
 static void
 decrease_brightness (PowerManagerButton *button)
 {
@@ -1495,13 +1548,25 @@ range_scroll_cb (GtkWidget *widget, GdkEvent *event, PowerManagerButton *button)
 static void
 range_show_cb (GtkWidget *widget, PowerManagerButton *button)
 {
+#if !GTK_CHECK_VERSION (3, 20, 0)
     GdkDeviceManager* manager = gdk_display_get_device_manager (gdk_display_get_default());
     GdkDevice* pointer = gdk_device_manager_get_client_pointer (manager);
+#else
+    GdkSeat   *seat = gdk_display_get_default_seat (gdk_display_get_default());
+    GdkDevice *pointer = gdk_seat_get_pointer (seat);
+#endif
+
     TRACE("entering");
     /* Release these grabs as they will cause a lockup if pkexec is called
      * for the brightness helper */
     if (pointer)
+    {
+#if !GTK_CHECK_VERSION (3, 20, 0)
         gdk_device_ungrab (pointer, GDK_CURRENT_TIME);
+#else
+        gdk_seat_ungrab (seat);
+#endif
+    }
 
     gtk_grab_remove (widget);
 }
@@ -1529,6 +1594,7 @@ power_manager_button_show_menu (PowerManagerButton *button)
     /* keep track of the menu while it's being displayed */
     button->priv->menu = menu;
     g_signal_connect(GTK_MENU_SHELL(menu), "deactivate", G_CALLBACK(menu_destroyed_cb), button);
+    gtk_menu_attach_to_widget (GTK_MENU (menu), GTK_WIDGET (button), NULL);
 
     for (item = g_list_first (button->priv->devices); item != NULL; item = g_list_next (item))
     {
@@ -1597,6 +1663,20 @@ G_GNUC_END_IGNORE_DEPRECATIONS
     gtk_menu_shell_append (GTK_MENU_SHELL(menu), mi);
     g_signal_connect (G_OBJECT(mi), "activate", G_CALLBACK(xfpm_preferences), NULL);
 
+#if GTK_CHECK_VERSION (3, 22, 0)
+    gtk_menu_popup_at_widget (GTK_MENU (menu),
+                              GTK_WIDGET (button),
+#ifdef XFCE_PLUGIN
+                              xfce_panel_plugin_get_orientation (button->priv->plugin) == GTK_ORIENTATION_VERTICAL
+                              ? GDK_GRAVITY_WEST : GDK_GRAVITY_NORTH,
+                              xfce_panel_plugin_get_orientation (button->priv->plugin) == GTK_ORIENTATION_VERTICAL
+                              ? GDK_GRAVITY_EAST : GDK_GRAVITY_SOUTH,
+#else
+                              GDK_GRAVITY_NORTH,
+                              GDK_GRAVITY_SOUTH,
+#endif
+                              NULL);
+#else
     gtk_menu_popup (GTK_MENU (menu),
                     NULL,
                     NULL,
@@ -1612,4 +1692,10 @@ G_GNUC_END_IGNORE_DEPRECATIONS
 #endif
                     0,
                     gtk_get_current_event_time ());
+#endif
+
+#ifdef XFCE_PLUGIN
+    xfce_panel_plugin_register_menu (button->priv->plugin,
+                                     GTK_MENU (menu));
+#endif
 }
