@@ -30,8 +30,12 @@
 #endif
 
 #include <stdio.h>
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
 #include <string.h>
+#endif
 
 #include <X11/X.h>
 #include <X11/XF86keysym.h>
@@ -125,9 +129,9 @@ xfpm_button_grab_keystring (XfpmButton *button, guint keycode)
 {
     Display *display;
     guint ret;
-    guint modmask = 0;
+    guint modmask = AnyModifier;
     
-    display = GDK_DISPLAY ();
+    display = gdk_x11_get_default_xdisplay ();
     
     gdk_error_trap_push ();
 
@@ -154,7 +158,7 @@ xfpm_button_grab_keystring (XfpmButton *button, guint keycode)
     }
 
     gdk_flush ();
-    gdk_error_trap_pop ();
+    gdk_error_trap_pop_ignored ();
     return TRUE;
 }
 
@@ -162,7 +166,7 @@ xfpm_button_grab_keystring (XfpmButton *button, guint keycode)
 static gboolean
 xfpm_button_xevent_key (XfpmButton *button, guint keysym , XfpmButtonKey key)
 {
-    guint keycode = XKeysymToKeycode (GDK_DISPLAY(), keysym);
+    guint keycode = XKeysymToKeycode (gdk_x11_get_default_xdisplay(), keysym);
 
     if ( keycode == 0 )
     {
@@ -208,12 +212,18 @@ xfpm_button_setup (XfpmButton *button)
 	
     if ( xfpm_button_xevent_key (button, XF86XK_MonBrightnessUp, BUTTON_MON_BRIGHTNESS_UP) )
 	button->priv->mapped_buttons |= BRIGHTNESS_KEY_UP;
-	
+
     if (xfpm_button_xevent_key (button, XF86XK_MonBrightnessDown, BUTTON_MON_BRIGHTNESS_DOWN) )
 	button->priv->mapped_buttons |= BRIGHTNESS_KEY_DOWN;
 	
     xfpm_button_xevent_key (button, XF86XK_Battery, BUTTON_BATTERY);
 
+    if ( xfpm_button_xevent_key (button, XF86XK_KbdBrightnessUp, BUTTON_KBD_BRIGHTNESS_UP) )
+	button->priv->mapped_buttons |= KBD_BRIGHTNESS_KEY_UP;
+
+    if (xfpm_button_xevent_key (button, XF86XK_KbdBrightnessDown, BUTTON_KBD_BRIGHTNESS_DOWN) )
+	button->priv->mapped_buttons |= KBD_BRIGHTNESS_KEY_DOWN;
+
     gdk_window_add_filter (button->priv->window, 
 			   xfpm_button_filter_x_events, button);
 }
