@@ -1,5 +1,5 @@
 /*
- * * Copyright (C) 2008-2009 Ali <aliov@xfce.org>
+ * * Copyright (C) 2008-2011 Ali <aliov@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -22,7 +22,6 @@
 #define __XFPM_MANAGER_H
 
 #include <glib-object.h>
-#include <dbus/dbus-glib.h>
 
 G_BEGIN_DECLS
 
@@ -48,7 +47,7 @@ typedef struct
 
 GType        		  xfpm_manager_get_type        (void) G_GNUC_CONST;
 
-XfpmManager    		 *xfpm_manager_new             (DBusGConnection *bus,
+XfpmManager    		 *xfpm_manager_new             (GDBusConnection *bus,
 							const gchar *client_id);
 
 void            	  xfpm_manager_start           (XfpmManager *manager);
