@@ -48,10 +48,10 @@
 
 static void xfpm_notify_finalize   (GObject *object);
 
-static NotifyNotification * xfpm_notify_new_notification_internal (const gchar *title, 
-								   const gchar *message, 
-								   const gchar *icon_name, 
-								   guint timeout, 
+static NotifyNotification * xfpm_notify_new_notification_internal (const gchar *title,
+								   const gchar *message,
+								   const gchar *icon_name,
+								   guint timeout,
 								   XfpmNotifyUrgency urgency) G_GNUC_MALLOC;
 
 #define XFPM_NOTIFY_GET_PRIVATE(o) \
@@ -60,13 +60,13 @@ static NotifyNotification * xfpm_notify_new_notification_internal (const gchar *
 struct XfpmNotifyPrivate
 {
     XfpmDBusMonitor    *monitor;
-    
+
     NotifyNotification *notification;
     NotifyNotification *critical;
-    
+
     gulong		critical_id;
     gulong		notify_id;
-    
+
     gboolean	        supports_actions;
     gboolean		supports_sync; /* For x-canonical-private-synchronous */
 };
@@ -86,14 +86,14 @@ xfpm_notify_get_server_caps (XfpmNotify *notify)
     GList *caps = NULL;
     notify->priv->supports_actions = FALSE;
     notify->priv->supports_sync    = FALSE;
-    
+
     caps = notify_get_server_caps ();
-    
-    if (caps != NULL) 
+
+    if (caps != NULL)
     {
 	if (g_list_find_custom (caps, "x-canonical-private-synchronous", (GCompareFunc) g_strcmp0) != NULL)
 	    notify->priv->supports_sync = TRUE;
-    
+
 	if (g_list_find_custom (caps, "actions", (GCompareFunc) g_strcmp0) != NULL)
 	    notify->priv->supports_actions = TRUE;
 
@@ -103,8 +103,8 @@ xfpm_notify_get_server_caps (XfpmNotify *notify)
 }
 
 static void
-xfpm_notify_check_server (XfpmDBusMonitor *monitor, 
-			  gchar *service_name, 
+xfpm_notify_check_server (XfpmDBusMonitor *monitor,
+			  gchar *service_name,
 			  gboolean connected,
 			  gboolean on_session,
 			  XfpmNotify *notify)
@@ -119,9 +119,9 @@ static void xfpm_notify_get_property (GObject *object,
 				      GParamSpec *pspec)
 {
     XfpmNotify *notify;
-    
+
     notify = XFPM_NOTIFY (object);
-    
+
     switch (prop_id)
     {
 	case PROP_ACTIONS:
@@ -165,18 +165,18 @@ static void
 xfpm_notify_init (XfpmNotify *notify)
 {
     notify->priv = XFPM_NOTIFY_GET_PRIVATE (notify);
-    
+
     notify->priv->notification = NULL;
     notify->priv->critical = NULL;
-    
+
     notify->priv->critical_id = 0;
     notify->priv->notify_id   = 0;
-    
+
     notify->priv->monitor = xfpm_dbus_monitor_new ();
     xfpm_dbus_monitor_add_service (notify->priv->monitor, G_BUS_TYPE_SESSION, "org.freedesktop.Notifications");
     g_signal_connect (notify->priv->monitor, "service-connection-changed",
 		      G_CALLBACK (xfpm_notify_check_server), notify);
-    
+
     xfpm_notify_get_server_caps (notify);
 }
 
@@ -186,24 +186,11 @@ xfpm_notify_finalize (GObject *object)
     XfpmNotify *notify;
 
     notify = XFPM_NOTIFY (object);
-    
+
     xfpm_notify_close_normal (notify);
     xfpm_notify_close_critical (notify);
-    
-    G_OBJECT_CLASS (xfpm_notify_parent_class)->finalize(object);
-}
 
-static void
-xfpm_notify_set_notification_icon (NotifyNotification *n, const gchar *icon_name )
-{
-    GdkPixbuf *pix = xfpm_icon_load (icon_name, 48);
-    
-    if ( pix )
-    {
-	notify_notification_set_image_from_pixbuf (n, pix);
-	g_object_unref ( G_OBJECT(pix));
-    }
-    
+    G_OBJECT_CLASS (xfpm_notify_parent_class)->finalize(object);
 }
 
 static NotifyNotification *
@@ -212,34 +199,29 @@ xfpm_notify_new_notification_internal (const gchar *title, const gchar *message,
 				       XfpmNotifyUrgency urgency)
 {
     NotifyNotification *n;
-    
+
 #ifdef NOTIFY_CHECK_VERSION
-#if NOTIFY_CHECK_VERSION (0, 7, 0) 
-    n = notify_notification_new (title, message, NULL);
+#if NOTIFY_CHECK_VERSION (0, 7, 0)
+    n = notify_notification_new (title, message, icon_name);
 #else
-    n = notify_notification_new (title, message, NULL, NULL);
+    n = notify_notification_new (title, message, icon_name, NULL);
 #endif
 #else
-    n = notify_notification_new (title, message, NULL, NULL);
+    n = notify_notification_new (title, message, icon_name, NULL);
 #endif
 
-    
-    if ( icon_name )
-    	xfpm_notify_set_notification_icon (n, icon_name);
+		/* Only set transient hint on non-critical notifications, so that the critical
+			 ones also end up in the notification server's log */
+		if (urgency != XFPM_NOTIFY_CRITICAL)
+				notify_notification_set_hint (n, "transient", g_variant_new_boolean (FALSE));
+		notify_notification_set_hint (n, "image-path", g_variant_new_string (icon_name));
 
     notify_notification_set_urgency (n, (NotifyUrgency)urgency);
-    
-    if ( timeout != 0)
-	notify_notification_set_timeout (n, timeout);
-    
-    return n;
-}
 
-static void
-xfpm_notify_closed_cb (NotifyNotification *n, XfpmNotify *notify)
-{
-    notify->priv->notification = NULL;
-    g_object_unref (G_OBJECT (n));
+    if (timeout != 0)
+				notify_notification_set_timeout (n, timeout);
+
+    return n;
 }
 
 static void
@@ -264,12 +246,12 @@ xfpm_notify_close_notification (XfpmNotify *notify )
 	g_source_remove (notify->priv->notify_id);
 	notify->priv->notify_id = 0;
     }
-    
+
     if ( notify->priv->notification )
     {
     	if (!notify_notification_close (notify->priv->notification, NULL))
 	    g_warning ("Failed to close notification\n");
-	
+
 	g_object_unref (G_OBJECT(notify->priv->notification) );
 	notify->priv->notification  = NULL;
     }
@@ -279,7 +261,7 @@ XfpmNotify *
 xfpm_notify_new (void)
 {
     static gpointer xfpm_notify_object = NULL;
-    
+
     if ( xfpm_notify_object != NULL )
     {
 	g_object_ref (xfpm_notify_object);
@@ -294,19 +276,17 @@ xfpm_notify_new (void)
 
 void xfpm_notify_show_notification (XfpmNotify *notify, const gchar *title,
 				    const gchar *text,  const gchar *icon_name,
-				    gint timeout, gboolean simple,
-				    XfpmNotifyUrgency urgency)
+				    gint timeout, XfpmNotifyUrgency urgency)
 {
     NotifyNotification *n;
-    
-    if ( !simple )
-        xfpm_notify_close_notification (notify);
-    
-    n = xfpm_notify_new_notification_internal (title, 
-				               text, icon_name, 
+
+    xfpm_notify_close_notification (notify);
+
+    n = xfpm_notify_new_notification_internal (title,
+				               text, icon_name,
 					       timeout, urgency);
 
-    xfpm_notify_present_notification (notify, n, simple);
+    xfpm_notify_present_notification (notify, n);
 }
 
 NotifyNotification *xfpm_notify_new_notification (XfpmNotify *notify,
@@ -316,8 +296,8 @@ NotifyNotification *xfpm_notify_new_notification (XfpmNotify *notify,
 						  guint timeout,
 						  XfpmNotifyUrgency urgency)
 {
-    NotifyNotification *n = xfpm_notify_new_notification_internal (title, 
-							           text, icon_name, 
+    NotifyNotification *n = xfpm_notify_new_notification_internal (title,
+							           text, icon_name,
 								   timeout, urgency);
     return n;
 }
@@ -327,27 +307,30 @@ void xfpm_notify_add_action_to_notification (XfpmNotify *notify, NotifyNotificat
 					    NotifyActionCallback callback, gpointer data)
 {
     g_return_if_fail (XFPM_IS_NOTIFY(notify));
-    
+
     notify_notification_add_action (n, id, action_label,
 				   (NotifyActionCallback)callback,
 				    data, NULL);
-    
+
 }
 
-void xfpm_notify_present_notification (XfpmNotify *notify, NotifyNotification *n, gboolean simple)
+static void
+xfpm_notify_closed_cb (NotifyNotification *n, XfpmNotify *notify)
+{
+    notify->priv->notification = NULL;
+    g_object_unref (G_OBJECT (n));
+}
+
+void xfpm_notify_present_notification (XfpmNotify *notify, NotifyNotification *n)
 {
     g_return_if_fail (XFPM_IS_NOTIFY(notify));
-    
-    if ( !simple )
-        xfpm_notify_close_notification (notify);
-    
-    if ( !simple )
-    {
-	g_signal_connect (G_OBJECT(n),"closed",
-			G_CALLBACK(xfpm_notify_closed_cb), notify);
-	notify->priv->notification = n;
-    }
-    
+
+    xfpm_notify_close_notification (notify);
+
+    g_signal_connect (G_OBJECT(n),"closed",
+											G_CALLBACK(xfpm_notify_closed_cb), notify);
+											notify->priv->notification = n;
+
     notify->priv->notify_id = g_idle_add ((GSourceFunc) xfpm_notify_show, n);
 }
 
@@ -356,31 +339,31 @@ void xfpm_notify_critical (XfpmNotify *notify, NotifyNotification *n)
     g_return_if_fail (XFPM_IS_NOTIFY (notify));
 
     xfpm_notify_close_critical (notify);
-    
+
     notify->priv->critical = n;
-    
-    g_signal_connect (G_OBJECT (n), "closed", 
+
+    g_signal_connect (G_OBJECT (n), "closed",
 		      G_CALLBACK (xfpm_notify_close_critical_cb), notify);
-		      
+
     notify->priv->critical_id = g_idle_add ((GSourceFunc) xfpm_notify_show, n);
 }
 
 void xfpm_notify_close_critical (XfpmNotify *notify)
 {
     g_return_if_fail (XFPM_IS_NOTIFY (notify));
-    
-    
+
+
     if (notify->priv->critical_id != 0)
     {
 	g_source_remove (notify->priv->critical_id);
 	notify->priv->critical_id = 0;
     }
-    
+
     if ( notify->priv->critical )
     {
     	if (!notify_notification_close (notify->priv->critical, NULL))
 	    g_warning ("Failed to close notification\n");
-	
+
 	g_object_unref (G_OBJECT(notify->priv->critical) );
 	notify->priv->critical  = NULL;
     }
@@ -389,6 +372,6 @@ void xfpm_notify_close_critical (XfpmNotify *notify)
 void xfpm_notify_close_normal  (XfpmNotify *notify)
 {
     g_return_if_fail (XFPM_IS_NOTIFY (notify));
-    
+
     xfpm_notify_close_notification (notify);
 }
